@@ -1,12 +1,3 @@
-# Test for one implementation of the interface
-import os
-from unittest import TestCase
-
-import pytest
-from integration_tests import IntegrationTests
-from lexicon.providers.namecheap import Provider
-
-
 """
 A note about running these tests against the live environment
 
@@ -49,16 +40,20 @@ The required Environment Variables for a live test are:
     export LEXICON_NAMECHEAP_DOMAIN={DOMAIN_1}
     export LEXICON_NAMECHEAP_DOMAINMANAGED={DOMAIN_2}
 """
+import os
+from unittest import TestCase
+
+import pytest
+from integration_tests import IntegrationTestsV2
+
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from integration_tests.IntegrationTests
+class NamecheapProviderTests(TestCase, IntegrationTestsV2):
+    """TestCase for Namecheap"""
 
-
-class NamecheapProviderTests(TestCase, IntegrationTests):
-
-    Provider = Provider
-    provider_name = 'namecheap'
+    provider_name = "namecheap"
 
     @property
     def domain(self):
@@ -66,20 +61,17 @@ class NamecheapProviderTests(TestCase, IntegrationTests):
         this can be used to override the tests
             LEXICON_NAMECHEAP_DOMAIN
         """
-        env_domain = os.environ.get('LEXICON_NAMECHEAP_DOMAIN', None)
-        return env_domain or 'example-aptise.com'
+        env_domain = os.environ.get("LEXICON_NAMECHEAP_DOMAIN", None)
+        return env_domain or "unittest2.dev"
 
     def _filter_query_parameters(self):
-        return ['ApiKey', 'UserName', 'ApiUser']
+        return ["ApiKey", "UserName", "ApiUser"]
 
     def _test_parameters_overrides(self):
-        return {
-            'auth_sandbox': True,
-            'auth_client_ip': '127.0.0.1'
-        }
+        return {"auth_sandbox": True, "auth_client_ip": "127.0.0.1"}
 
     @pytest.mark.skip(reason="can not set ttl when creating/updating records")
-    def test_Provider_when_calling_list_records_after_setting_ttl(self):
+    def test_provider_when_calling_list_records_after_setting_ttl(self):
         return
 
 
@@ -94,7 +86,8 @@ class NamecheapManagedProviderTests(NamecheapProviderTests):
 
     Note we define a `provider_variant`, which will change the cassette path.
     """
-    provider_variant = 'managed'
+
+    provider_variant = "managed"
 
     @property
     def domain(self):
@@ -102,5 +95,5 @@ class NamecheapManagedProviderTests(NamecheapProviderTests):
         this can be used to override the tests
             LEXICON_NAMECHEAP_DOMAINMANAGED
         """
-        env_domain = os.environ.get('LEXICON_NAMECHEAP_DOMAINMANAGED', None)
-        return env_domain or 'example-aptise-2.com'
+        env_domain = os.environ.get("LEXICON_NAMECHEAP_DOMAINMANAGED", None)
+        return env_domain or "unittest-seconddomain.dev"
