@@ -1,18 +1,9 @@
-# Test for one implementation of the interface
-import os
-from unittest import TestCase
-
-import pytest
-from integration_tests import IntegrationTests
-from lexicon.providers.nfsn import Provider
-
-
 """
 Some small info about running live tests.
 
 NFSN doesn't have trial accounts, so these tests can only
 be run by those with an NFSN account. NFSN also requires
-you to have an API key. More info here: 
+you to have an API key. More info here:
 
 https://members.nearlyfreespeech.net/wiki/API/Introduction
 
@@ -25,16 +16,19 @@ parameters must be provided:
 - LEXICON_NFSN_TOKEN -> Your API Key
 - LEXICON_NFSN_DOMAIN -> Domain you want to test with
 """
+from unittest import TestCase
+
+from integration_tests import IntegrationTestsV2
+
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from integration_tests.IntegrationTests
+class NFSNProviderTests(TestCase, IntegrationTestsV2):
+    """TestCase for NFSN"""
 
-
-class NFSNProviderTests(TestCase, IntegrationTests):
-    Provider = Provider
-    provider_name = 'nfsn'
-    domain = 'koupia.xyz'
+    provider_name = "nfsn"
+    domain = "koupia.xyz"
 
     def _filter_headers(self):
-        return ['X-NFSN-Authentication']
+        return ["X-NFSN-Authentication"]
