@@ -1,21 +1,18 @@
-# Test for one implementation of the interface
+"""Integration tests for Softlayer"""
 from unittest import TestCase
 
-import pytest
-from integration_tests import IntegrationTests
-from lexicon.providers.softlayer import Provider
+from integration_tests import IntegrationTestsV1
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
+# TODO: migrate to IntegrationTestsV2 and its extended test suite
+class SoftLayerProviderTests(TestCase, IntegrationTestsV1):
+    """TestCase for SoftLayer"""
 
-
-class SoftLayerProviderTests(TestCase, IntegrationTests):
-
-    Provider = Provider
-    provider_name = 'softlayer'
-    domain = 'example.com'
+    provider_name = "softlayer"
+    domain = "example.com"
 
     # SoftLayer does not provide a sandbox API; actual credentials are required
     # Keeping this here for when fixtures need to be regenerated
@@ -26,9 +23,3 @@ class SoftLayerProviderTests(TestCase, IntegrationTests):
     #        'auth_api_key': 'bar'
     #        })
     #    return options
-
-    # TODO: the following skipped suite and fixtures should be enabled
-    @pytest.fixture(autouse=True)
-    def skip_suite(self, request):
-        if request.node.get_marker('ext_suite_1'):
-            pytest.skip('Skipping extended suite')
